<!-- Adapted from https://www.w3schools.com/php/php_form_validation.asp -->
<!DOCTYPE HTML>
<html>
<head>
<style>
body {font: 1em Verdana; margin: 2em;}
div {margin: 1em;}
input[type=text] {
    padding: .5em;
    margin: .5em 0;
    border: 1px solid silver;
    border-radius: .3em;
    box-sizing: border-box;
}
button {
   margin-left: 1em;
   padding      : .4em .8em;
   font         : bold .8em sans-serif;
   color        : white;
   border       : 2px ;
   border-radius: 5px;
   background   : blueviolet;
}
label {display:block;}
.error {color: #FF0000;}
</style>
</head>
<body>

<?php
// define variables and set to empty values
$nameErr = $emailErr = $websiteErr = "";
$name = $email = $comment = $website = "";

// If user has clicked Submit, process the form inputs
if (isset($_POST['submit'])) {
   // Check if name is empty; if yes, set the error message;
   //   if not, clean the data, and check if alphabetic
   if (empty($_POST["name"])) {
      $nameErr = "Name is required"; }
   else {
      $name = clean_data($_POST["name"]);
      // use regular expression tocheck if name only contains letters and whitespace
      if (!preg_match("/^[a-zA-Z ]*$/", $name)) {
         $nameErr = "Only letters and white space allowed";
      }
   }
   // Check if email is empty; if yes, set the error message;
   //   if not, clean the data, and check if it passes filter validation
   if (empty($_POST["email"])) {
      $emailErr = "Email is required"; }
   else {
      $email = clean_data($_POST["email"]);
      // check if e-mail address is well-formed
      if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
         $emailErr = "Invalid email format";
      }
   }
   // Check if website is empty; if yes, set empty string;
   //   if not, clean the data, and check if it passes filter validation
   if (empty($_POST["website"])) {
      $website = ""; }
   else {
      $website = clean_data($_POST["website"]);
      // check if URL address syntax is valid
      if (!filter_var($website, FILTER_VALIDATE_URL)) {
         $websiteErr = "Invalid URL";
      }
   }
   // Check if comment is empty; if yes, set empty string;
   //   if not, clean the data
   if (empty($_POST["comment"])) {
      $comment = ""; }
   else {
      $comment = clean_data($_POST["comment"]);
   }
}

function clean_data($data) {
   $data = trim($data);               // removes whitespace from beginning and end of a string
   $data = stripslashes($data);       // removes backslashes, e.g., escape sequences
   $data = htmlspecialchars($data);   // converts some predefined characters to HTML entities
   return $data;
}
?>

<h2>PHP Form Validation Example</h2>
<p><span class="error">* required field.</span></p>
<form method="post">
   <div>
     <label>Name</label>
     <input type="text" name="name" value="<?php echo $name;?>">
     <span class="error">* <?php echo $nameErr;?></span>
   </div>

   <div>
     <label>Email</label>
     <input type="text" name="email" value="<?php echo $email;?>">
     <span class="error">* <?php echo $emailErr;?></span>
   </div>

   <div>
     <label>Website</label>
     <input type="text" name="website" value="<?php echo $website;?>">
     <span class="error"><?php echo $websiteErr;?></span>
   </div>

   <div>
     <label>Comment</label>
     <textarea name="comment" rows="5" cols="40"><?php echo $comment;?></textarea>
   </div>

   <button type="submit" id="submit" name="submit">Submit</button>

</form>
<?php
echo "<h2>Your Input:</h2>";
echo $name;
echo "<br>";
echo $email;
echo "<br>";
echo $website;
echo "<br>";
echo $comment;
?>
</body>
</html>
